==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/Stacked100SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSplineAreaSeriesDescriptionMetadata } from "./StackedSplineAreaSeriesDescriptionMetadata";
import { Stacked100SplineAreaSeriesDescription } from "./Stacked100SplineAreaSeriesDescription";
/**
 * @hidden
 */
var Stacked100SplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Stacked100SplineAreaSeriesDescriptionMetadata, _super);
    function Stacked100SplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100SplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (Stacked100SplineAreaSeriesDescriptionMetadata.a == null) {
            Stacked100SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Stacked100SplineAreaSeriesDescriptionMetadata.c(Stacked100SplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(Stacked100SplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(Stacked100SplineAreaSeriesDescriptionMetadata.a);
    };
    Stacked100SplineAreaSeriesDescriptionMetadata.c = function (a) {
        StackedSplineAreaSeriesDescriptionMetadata.c(a);
    };
    Stacked100SplineAreaSeriesDescriptionMetadata.d = function (a) {
        Stacked100SplineAreaSeriesDescriptionMetadata.b(a);
        a.aa("Stacked100SplineAreaSeries", function () { return new Stacked100SplineAreaSeriesDescription(); });
        a.z("Stacked100SplineAreaSeries", Stacked100SplineAreaSeriesDescriptionMetadata.a);
    };
    Stacked100SplineAreaSeriesDescriptionMetadata.$t = markType(Stacked100SplineAreaSeriesDescriptionMetadata, 'Stacked100SplineAreaSeriesDescriptionMetadata');
    Stacked100SplineAreaSeriesDescriptionMetadata.a = null;
    return Stacked100SplineAreaSeriesDescriptionMetadata;
}(Base));
export { Stacked100SplineAreaSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/Stacked100SplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSplineAreaSeriesDescriptionMetadata } from "./StackedSplineAreaSeriesDescriptionMetadata";
import { Stacked100SplineAreaSeriesDescription } from "./Stacked100SplineAreaSeriesDescription";
/**
 * @hidden
 */
var Stacked100SplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Stacked100SplineAreaSeriesDescriptionMetadata, _super);
    function Stacked100SplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Stacked100SplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (Stacked100SplineAreaSeriesDescriptionMetadata.a == null) {
            Stacked100SplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Stacked100SplineAreaSeriesDescriptionMetadata.c(Stacked100SplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.k(Stacked100SplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(Stacked100SplineAreaSeriesDescriptionMetadata.a);
    };
    Stacked100SplineAreaSeriesDescriptionMetadata.c = function (a) {
        StackedSplineAreaSeriesDescriptionMetadata.c(a);
    };
    Stacked100SplineAreaSeriesDescriptionMetadata.d = function (a) {
        Stacked100SplineAreaSeriesDescriptionMetadata.b(a);
        a.ac("Stacked100SplineAreaSeries", function () { return new Stacked100SplineAreaSeriesDescription(); });
        a.ab("Stacked100SplineAreaSeries", Stacked100SplineAreaSeriesDescriptionMetadata.a);
    };
    Stacked100SplineAreaSeriesDescriptionMetadata.$t = markType(Stacked100SplineAreaSeriesDescriptionMetadata, 'Stacked100SplineAreaSeriesDescriptionMetadata');
    Stacked100SplineAreaSeriesDescriptionMetadata.a = null;
    return Stacked100SplineAreaSeriesDescriptionMetadata;
}(Base));
export { Stacked100SplineAreaSeriesDescriptionMetadata };
